---
template: "home.html"
title: "nakamochi"
extra:
  landing: true
  tagline: "a device for complete privacy and financial independence leveraging bitcoin and lightning networks"
---
## Motivation

Nowadays, there are many web and mobile apps providing bitcoin and lightning wallets
functionality. They are mostly known as [SPV], Simplified Payment Verification clients
which connect to a [full node]. Likewise, [hardware wallets] also typically require
a companion app which in turn connects to a full node run by someone else.

Historically, bitcoin - and especially lightning - nodes have been run by
organizations and people with knowledge in cryptography, system networks and
software engineering.

Nakamochi takes on the challenge to make such nodes usable to a broader audience.
Just like a coffee maker or a microwave oven, we believe anyone should be able
to run a node at home and reach 100% privacy and independence. Running one's own
full node also helps the whole Bitcoin network to remain decentralized.

[SPV]: https://developer.bitcoin.org/devguide/operating_modes.html#simplified-payment-verification-spv
[full node]: https://bitcoin.org/en/full-node#what-is-a-full-node
[hardware wallets]: https://bitcoin.org/en/wallets/hardware/

## The name

The name "nakamochi" comes from putting together [Satoshi Nakamoto], the founder
of Bitcoin, and a
[famous Japanese handheld digital pet](https://en.wikipedia.org/wiki/Tamagotchi)
to emphasize personal, self-hosting.

[Satoshi Nakamoto]: https://en.bitcoin.it/wiki/Satoshi_Nakamoto

## Editions

The following editions are listed in an order of increasing ease of use.
It is always a trade-off between the costs and effort oneself has to put
in and the trust into the manufacturing companies and their supply chain.

<div class="text-media-card">
  <div class="card-text">

All the editions have something in common: the touch screen user interface and
automated system updates. Even at a high level of distrust one can still benefit
from the open source software and, equally important, system updates.

  </div>
  <figure class="card-media screenshot">
    <img src="/assets/ngui-screenshot.png" alt="nakamochi touchscreen GUI screenshot">
    <figcaption>nakamochi touchscreen GUI screenshot</figcaption>
  </figure>
</div>

### DIY

<div class="text-media-card">
  <div class="card-text">

The [DIY version](https://git.qcode.ch/nakamochi/3d#diy-version-fff) is designed using
only off-the-shelf hardware components and 3D printed parts. It is a running system
and you can source and even replace the hardware. Everything is open source and freely
accessible for everyone. You can of course buy the whole kit from us to make things easier.
Enjoy checking out the source code, CAD designs and schematics. You can tinker here, just
be sure that the device still works after that.

  </div>
  <figure class="card-media bogen">
    <img src="/assets/diy-assembly.png" alt="DIY version assembly">
    <figcaption>DIY version assembly</figcaption>
  </figure>
</div>

### DIY+

<div class="text-media-card">
  <div class="card-text">

If you want to profit from some product engineering but still want to use
off-the-shelf components, we recommend the DIY+ version. As the name tells,
the "plus" in this version improves some characteristics of the device.

For example, the previous DIY version may suffer from overheating in certain
conditions. This edition improves heat dissipation while keeping the device
completely silent, fanless.

However, this edition still requires technical knowledge in CNC machining
and 3D printing.

  </div>
  <div class="card-media">
    <figure class="bogen">
      <img src="/assets/diyplus-assembly.png" alt="DIY+ version assembly">
      <figcaption>DIY+ version assembly</figcaption>
    </figure>
    <figure>
      <img src="/assets/ir1166.jpg" alt="DIY+ heat dissipation">
      <figcaption>DIY+ heat dissipation during initial block download</figcaption>
    </figure>
  </div>
</div>

### PRO

<div class="text-media-card">
  <div class="card-text">

If you are mostly interested in the freedom of the Bitcoin Standard, helping
the Bitcon network to remain decentralized, and want a device that just works
without a DIY-like technical knowledge in hardware design and software engineering,
the PRO edition is the one for you.

We are taking all the knowledge and learnings from the DIY versions and designing
most of the parts ourselves here: from mechanical parts and enclosure to PCBs for
an optimal device solution where hardware and software work very well together.
All of the work is open source.

The PRO edition is still work-in-progress.

  </div>
  <figure class="card-media bogen">
    <img src="/assets/pro-question-mark.png" alt="PRO version in progress">
    <figcaption>PRO version in progress</figcaption>
  </figure>
</div>
